OC.L10N.register(
    "files_sharing",
    {
    "Shared with you" : "Bendrinama su jumis",
    "Nothing shared with you yet" : "Kol kas su jumis nieko nėra bendrinama",
    "Files and folders others share with you will show up here" : "Čia bus rodomi failai ir aplankai, kuriuos su jumis bendrina kiti asmenys",
    "Shared with others" : "Bendrinama su kitais",
    "Nothing shared yet" : "Kol kas nieko nebendrinama",
    "Files and folders you share will show up here" : "Čia bus rodomi jūsų bendrinami failai ir aplankai",
    "Shared by link" : "Bendrinama pagal nuorodą",
    "Files and folders you share by link will show up here" : "Čia bus rodomi failai ir aplankai, kuriuos bendrinate pagal nuorodą",
    "Deleted shares" : "Ištrinti viešiniai",
    "No deleted shares" : "Ištrintų viešinių nėra",
    "Shares you deleted will show up here" : "Čia bus rodomi jūsų ištrinti viešiniai",
    "Shares" : "Viešiniai",
    "No shares" : "Nėra jokių viešinių",
    "Shares will show up here" : "Čia bus rodomi viešiniai",
    "Restore share" : "Atkurti viešinį",
    "Something happened. Unable to restore the share." : "Kažkas nutiko. Nepavyko atkurti viešinio.",
    "Accept share" : "Priimti viešinį",
    "Something happened. Unable to accept the share." : "Kažkas nutiko. Nepavyko priimti viešinio.",
    "Reject share" : "Atmesti viešinį",
    "Something happened. Unable to reject the share." : "Kažkas nutiko. Nepavyko atmesti viešinį.",
    "This will stop your current uploads." : "Tai sustabdys dabartinius įkėlimus.",
    "Move or copy" : "Perkelti ar kopijuoti",
    "Download" : "Atsisiųsti",
    "Delete" : "Ištrinti",
    "You can upload into this folder" : "Galite įkelti į šį aplanką",
    "Terms of service" : "Naudojimosi sąlygos",
    "No compatible server found at {remote}" : "Nerasta jokio suderinamo serverio ties {remote}",
    "Invalid server URL" : "Neteisingas serverio URL adresas",
    "Failed to add the public link to your Nextcloud" : "Nepavyko pridėti viešosios nuorodos į jūsų Nextcloud",
    "No expiration date set" : "Dalinimosi pabaigos data yra nenustatyta",
    "Shared by" : "Bendrina",
    "File shares" : "Bendrinami failai",
    "Downloaded via public link" : "Atsisiųstas per viešąją nuorodą",
    "Downloaded by {email}" : "Atsisiuntė {email}",
    "{file} downloaded via public link" : "{file} atsisiųstas per viešąją nuorodą",
    "{email} downloaded {file}" : "{email} atsisiuntė {file}",
    "Shared with group {group}" : "Bendrinama su grupe {group}",
    "Removed share for group {group}" : "Nebesidalinama su grupe: {group}",
    "{actor} shared with group {group}" : "{actor} pradėjo bendrinti su grupe {group}",
    "{actor} removed share for group {group}" : "{actor} nustojo dalintis su {group} grupe",
    "You shared {file} with group {group}" : "Jūs pradėjote bendrinti {file} su grupe {group}",
    "You removed group {group} from {file}" : "Pašalinote grupę {group} iš {file}",
    "{actor} shared {file} with group {group}" : "{actor} pradėjo bendrinti {file} su grupe {group}",
    "{actor} removed group {group} from {file}" : "{actor} pašalino grupę {group} iš {file}",
    "Shared as public link" : "Bendrinama kaip viešoji nuoroda",
    "Removed public link" : "Pašalinta viešą nuorodą",
    "Public link expired" : "Pasibaigė viešosios nuorodos galiojimo laikas",
    "{actor} shared as public link" : "{actor} pradėjo bendrinti kaip viešąją nuorodą",
    "{actor} removed public link" : "{actor} pašalino viešąją nuorodą",
    "Public link of {actor} expired" : "Pasibaigė nuorodos, priklausančios {actor}, galiojimo laikas",
    "You shared {file} as public link" : "Jūs pradėjote bendrinti {file} kaip viešąją nuorodą",
    "You removed public link for {file}" : "Jūs pašalinote viešą {file} nuorodą",
    "Public link expired for {file}" : "Pasibaigė nuorodos galiojimo laikas skirtas {file}",
    "{actor} shared {file} as public link" : "{actor} pradėjo bendrinti {file} kaip viešąją nuorodą",
    "{actor} removed public link for {file}" : "{actor} pašalino viešąją \"{file}\" nuorodą",
    "Public link of {actor} for {file} expired" : "Pasibaigė nuorodos galiojimo laikas duomenims {file}, bendrintiems {actor}",
    "{user} accepted the remote share" : "{user} priėmė bendrinamus duomenis",
    "{user} declined the remote share" : "{user} atmetė duomenų dalinimąsi",
    "You received a new remote share {file} from {user}" : "Jūs gavote naują duomenis \"{file}\" iš kito serverio nuo {user}",
    "{user} accepted the remote share of {file}" : "{user} priėmė bendrinamus duomenis \"{file}\"",
    "{user} declined the remote share of {file}" : "{user} atmetė duomenų \"{file}\" dalinimąsį",
    "{user} unshared {file} from you" : "{user} nustojo bendrinti su jumis {file}",
    "Shared with {user}" : "Pradėta bendrinti su {user}",
    "Removed share for {user}" : "Nustota dalintis su {user}",
    "You removed yourself" : "Jūs pašalinote save",
    "{actor} removed themselves" : "{actor} pašalino save",
    "{actor} shared with {user}" : "{actor} pradėjo bendrinti su {user}",
    "{actor} removed share for {user}" : "{actor} nustojo dalintis su {user}",
    "Shared by {actor}" : "Pasidalino {actor}",
    "{actor} removed share" : "{actor} nustojo dalintis",
    "Share expired" : "Viešinys nebegalioja",
    "You shared {file} with {user}" : "Pasidalinote {file} su {user}",
    "You removed {user} from {file}" : "Nebesidalinate {file} su {user}",
    "You removed yourself from {file}" : "Nebesidalinate {file} su savimi",
    "{actor} removed themselves from {file}" : "{actor} nebesidalina {file} su savimi",
    "{actor} shared {file} with {user}" : "{actor} pasidalino {file} su {user}",
    "{actor} removed {user} from {file}" : "{actor} nebesidalina {file} su {user}",
    "{actor} shared {file} with you" : "{actor} pradėjo bendrinti su jumis {file}",
    "{actor} removed you from the share named {file}" : "{actor} pašalino jus iš viešinio, pavadinimu {file}",
    "Share for file {file} expired" : "Failo {file} viešinys nebegalioja",
    "A file or folder shared by mail or by public link was <strong>downloaded</strong>" : "Buvo <strong>atsisiųstas</strong> el. paštu ar viešąja nuoroda bendrinamas failas ar aplankas",
    "A file or folder was shared from <strong>another server</strong>" : "Failas ar aplankas buvo pradėtas bendrinti iš <strong>kito serverio</strong>",
    "A file or folder has been <strong>shared</strong>" : "Failas ar aplankas <strong>pradėtas bendrinti</strong>",
    "Wrong share ID, share doesn't exist" : "Neteisingas dalinamų duomenų ID",
    "Could not delete share" : "Nepavyko nustoti dalintis duomenimis",
    "Please specify a file or folder path" : "Nurodykite kelią iki duomenų",
    "Wrong path, file/folder doesn't exist" : "Neteisingas kelias, failo/aplanko nėra",
    "Could not create share" : "Nepavyko sukurti viešinio",
    "invalid permissions" : "neteisingi leidimai",
    "Please specify a valid user" : "Nurodykite naudotoją",
    "Group sharing is disabled by the administrator" : "Administratorius išjungė bendrinimą su grupėmis",
    "Please specify a valid group" : "Nurodykite teisingą grupę",
    "Public upload disabled by the administrator" : "Įkėlimas viešam naudojimui yra išjungtas",
    "Public upload is only possible for publicly shared folders" : "Duomenų įkėlimas viešam naudojimui galimas tik į viešai dalinamus aplankus",
    "Invalid date, date format must be YYYY-MM-DD" : "Netinkamas datos formavimas. Privaloma: YYYY-MM-DD",
    "You cannot share to a Circle if the app is not enabled" : "Negalite dalintis su naudotojų ratu, kai įskiepis \"Circle\" neveikia",
    "Please specify a valid circle" : "Pasirinkite naudotojų ratą",
    "Unknown share type" : "Nežinomas bendrinamų duomenų tipas",
    "Not a directory" : "Nėra katalogas",
    "Could not lock node" : "Nepavyko užrakinti mazgo",
    "Could not lock path" : "Nepavyko užrakinti kelio",
    "Wrong or no update parameter given" : "Neperduoti atnaujinimo parametrai",
    "Can't change permissions for public share links" : "Negalima keisti leidimų viešai bendrinamoms nuorodoms",
    "shared by %s" : "bendrina %s",
    "Download all files" : "Atsisiųsti visus failus ",
    "Direct link" : "Tiesioginė nuoroda",
    "Add to your Nextcloud" : "Pridėti į savo Nextcloud",
    "Share API is disabled" : "Bendrinimo API yra išjungtas",
    "File sharing" : "Failų pasidalinimas",
    "Accept" : "Priimti",
    "Reject" : "Atmesti",
    "Sharing" : "Bendrinimas",
    "Accept user and group shares by default" : "Pagal numatymą, priimti naudotojo ir grupių viešinius",
    "Allow editing" : "Leisti redaguoti",
    "Allow resharing" : "Leisti bendrinti iš naujo",
    "Expiration date enforced" : "Aktyvuotas galiojimo laikas",
    "Set expiration date" : "Nustatyti galiojimo pabaigos datą",
    "Note to recipient" : "Pastaba gavėjui",
    "Unshare" : "Nebesidalinti",
    "group" : "grupė",
    "conversation" : "pokalbis",
    "remote" : "nuotolinis",
    "remote group" : "nuotolinė grupė",
    "guest" : "svečias",
    "Added by {initiator}" : "Pridėjo {initiator}",
    "Via folder" : "Per aplanką",
    "Internal link" : "Vidinė nuoroda",
    "Link copied" : "Nuoroda nukopijuota",
    "Cannot copy, please copy the link manually" : "Nepavyksta nukopijuoti, nukopijuokite nuorodą rankiniu būdu",
    "Copy to clipboard" : "Kopijuoti į iškarpinę",
    "Only works for users with access to this folder" : "Veikia tik naudotojams, turintiems prieigą prie šio aplanko",
    "Only works for users with access to this file" : "Veikia tik naudotojams, turintiems prieigą prie šio failo",
    "Please enter the following required information before creating the share" : "Prieš sukurdami viešinį, įveskite šią reikiamą informaciją",
    "Password protection" : "Password protection",
    "Enter a password" : "Enter a password",
    "Cancel" : "Atsisakyti",
    "Read only" : "Tik skaitymui",
    "Allow upload and editing" : "Leisti įkelti ir redaguoti",
    "File drop (upload only)" : "Failų įmetimas (tik įkėlimas)",
    "Hide download" : "Slėpti atsisiuntimą",
    "Password protect" : "Apsaugoti slaptažodžiu",
    "Add another link" : "Pridėti kitą nuorodą",
    "Create a new share link" : "Sukurti naują bendrinimo nuorodą",
    "Share link" : "Bendrinimo nuoroda",
    "No recommendations. Start typing." : "Rekomendacijų nėra. Pradėkite rašyti.",
    "Resharing is not allowed" : "Bendrinimas iš naujo yra neleidžiamas",
    "Name or email address …" : "Vardas ar el. pašto adresas…",
    "Name or federated cloud ID …" : "Vardas ar federacinės debesijos ID…",
    "Name, federated cloud ID or email address …" : "Vardas, federacinės debesijos ID arba el. pašto adresas…",
    "Name …" : "Vardas…",
    "Searching …" : "Ieškoma…",
    "No elements found." : "Nerasta jokių elementų.",
    "Search globally" : "Ieškoti visur",
    "Toggle list of others with access to this directory" : "Perjungti sąrašą kitų asmenų, turinčių prieigą prie šio katalogo",
    "Toggle list of others with access to this file" : "Perjungti sąrašą kitų asmenų, turinčių prieigą prie šio failo",
    "Unable to load the shares list" : "Nepavyko įkelti viešinių sąrašo",
    "this share just expired." : "šis viešinys ką tik nustojo galioti.",
    "Error creating the share" : "Klaida kuriant viešinį",
    "Error updating the share" : "Klaida atnaujinant viešinį",
    "Shared" : "Pasidalinta",
    "Share" : "Dalintis",
    "Shared with" : "Bendrinama su",
    "Shared with you and the group {group} by {owner}" : "{owner} pasidalino su jumis ir grupe {group}",
    "Shared with you and {circle} by {owner}" : "{owner} pasidalino su jumis ir {circle}",
    "Shared with you and the conversation {conversation} by {owner}" : "{owner} pasidalino su jumis ir pokabliu {conversation}",
    "Shared with you in a conversation by {owner}" : "{owner} pasidalino su jumis pokalbyje",
    "Shared with you by {owner}" : "{owner} pasidalino su jumis",
    "No entries found in this folder" : "Šiame aplanke įrašų nerasta",
    "Name" : "Pavadinimas",
    "Share time" : "Bendrinimo laikas",
    "Expiration date" : "Pabaigos data",
    "Sorry, this link doesn’t seem to work anymore." : "Nuoroda yra neveiksni.",
    "Reasons might be:" : "Galimos priežastys:",
    "the item was removed" : "elementas buvo pašalintas",
    "the link expired" : "baigėsi nuorodos galiojimo laikas",
    "sharing is disabled" : "dalinimasis yra išjungtas",
    "For more info, please ask the person who sent this link." : "Dėl tikslesnės informacijos susisiekite su asmeniu atsiuntusiu nuorodą.",
    "Share note" : "Pasidalinimo pastaba",
    "Toggle grid view" : "Rodyti tinkleliu",
    "Download %s" : "Atsisiųsti %s",
    "Upload files to %s" : "Įkelkite failus gavėjui %s",
    "Note" : "Pastaba",
    "Select or drop files" : "Pasirinkite arba vilkite failus",
    "Uploading files…" : "Įkeliami failai…",
    "Uploaded files:" : "Įkelti failai:",
    "By uploading files, you agree to the %1$sterms of service%2$s." : "Įkeldami failus, sutinkate su %1$snaudojimosi sąlygomis%2$s.",
    "could not delete share" : "nepavyko nustoti dalintis duomenimis"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
